<?php

namespace Drupal\entity_bundle\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Defines the 'entity_bundle' field type.
 *
 * @FieldType(
 *   id = "entity_bundle",
 *   label = @Translation("Entity bundle reference"),
 *   description = @Translation("Render the referenced entity."),
 *   category = @Translation("Reference"),
 *   default_formatter = "entity_bundle_formatter",
 *   cardinality = 1,
 *   default_widget = "entity_bundle_widget",
 *   field_types = {
 *     "entity_bundle"
 *   }
 * )
 */
class EntityBundle extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['bundles'] = DataDefinition::create('string')
      ->setLabel(t('Select option'))
      ->setRequired(FALSE);
    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    $columns = [
      'bundles' => [
        'type' => 'varchar',
        'length' => 255,
      ],
    ];

    return [
      'columns' => $columns,
      'indexes' => [],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $value = $this->get('bundles')->getValue();
    return $value === NULL || $value === '';
  }

  /**
   * Define el formulario del campo.
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    $element = parent::fieldSettingsForm($form, $form_state);

    $element['entity_type'] = [
      '#type' => 'select',
      '#title' => $this->t('Select entity bundle type'),
      '#description' => $this->t("Select entity bundle type that will support the field."),
      '#options' => [
        'node' => $this->t('Content type'),
        'taxonomy_term' => $this->t('Vocabulary'),
      ],
      '#default_value' => $this->getSetting('entity_type'),
    ];
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings() {
    return [
      'entity_type' => '',
    ];
  }

}
